# Changelog

## [2.0.1a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.0.1a1) (2024-11-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.0.0...2.0.1a1)

**Merged pull requests:**

- fix: allow latest bus client version [\#264](https://github.com/OpenVoiceOS/OVOS-workshop/pull/264) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
